#include "testApp.h"

int switchPin = 0;
int pot1Pin= 1;
int pot2Pin= 2;
int ledPin = 11;

// in this app we control the shaper of powf with several rectangles

//--------------------------------------------------------------
void testApp::setup(){	 
	
	ofSetVerticalSync(true);
	ofBackground(255,0,130);
	
	ofSetFrameRate(60);

	
	ard.connect("/dev/tty.usbserial-A70064TO", 57600);	// AB CHANGED FROM SETUP TO CONNECT
	
	bSetupArduino	= false;							// flag so we setup arduino when its ready, you don't need to touch this :)
	bUseDelay		= true;								// this is for decimila boards.  they reset and take some time to get commands on connection
	
	// now we are using multiple rectangles....
	// set the "a" and "b" positions of the
	for (int i = 0; i < 10; i++){
		myRectangles[i].posa.x = 0;
		myRectangles[i].posa.y = 10 + i*20;
		myRectangles[i].posb.x = 1000;
		myRectangles[i].posb.y = 10 + i*20;
		myRectangles[i].shaper = 0.4 + 0.2 * i;
		myRectangles[i].interpolateByPct(0);	// start at 0 pct
	}
	pct = 0;							// a variable we can alter...
} 


//--------------------------------------------------------------
void testApp::update(){

	
	if (((bUseDelay == true) && (ofGetElapsedTimef() > 5)) || (bUseDelay == false)){
		
		// 1st: setup the arduino if haven't already:
		if (bSetupArduino == false) setupArduino();
		
		// 2nd do the update of the arduino
		updateArduino();

	}
	float potValue = ard.getAnalog(pot1Pin);

	pct += potValue/1024;							// increase by a certain amount
	if (pct > 1) pct = 0;					// just between 0 and 1 (0% and 100%)
	for (int i = 0; i < 10; i++){
		myRectangles[i].interpolateByPct(pct);		// go between pta and ptb
	}


	
}

//--------------------------------------------------------------
void testApp::setupArduino(){
	// this is where you setup all the pins and pin modes, etc
	for (int i = 0; i < 13; i++)
	{
		ard.sendDigitalPinMode(i, ARD_OUTPUT);
	}

	// switch and pot pins have to be set to analog
	ard.sendAnalogPinReporting(switchPin, ARD_ANALOG);	
	ard.sendAnalogPinReporting(pot1Pin, ARD_ANALOG);	
	ard.sendAnalogPinReporting(pot2Pin, ARD_ANALOG);	

	// ledPin is output
	ard.sendDigitalPinMode(ledPin, ARD_OUTPUT);		// on diecimelia: 11 pwm?
	bSetupArduino = true;						// do this once


}

//--------------------------------------------------------------



void testApp::updateArduino(){
	

	ard.update();

	
	// update the arduino, get any data or messages: 
	if (ard.getAnalog(switchPin) == 0){
		ofSetFullscreen(true);
	} else {
		ofSetFullscreen(false);
	}


		
}


//--------------------------------------------------------------
void testApp::draw(){
	for (int i = 0; i < 10; i++){
		
		if (i != 3) ofSetColor(198,246,55);
		else ofSetColor(255,0,0);
		myRectangles[i].draw();
	}
}


//--------------------------------------------------------------
void testApp::keyPressed  (int key){ 
	
}

//--------------------------------------------------------------
void testApp::keyReleased(int key){ 
	
}

//--------------------------------------------------------------
void testApp::mouseMoved(int x, int y ){
	
}

//--------------------------------------------------------------
void testApp::mouseDragged(int x, int y, int button){

}

//--------------------------------------------------------------
void testApp::mousePressed(int x, int y, int button){
	ard.sendDigital(ledPin, ARD_HIGH);
}

//--------------------------------------------------------------
void testApp::mouseReleased(){
	ard.sendDigital(ledPin, ARD_LOW);
}



